/****************************************************************************
** Meta object code from reading C++ file 'qmodbusserver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtserialbus/src/serialbus/qmodbusserver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmodbusserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13QModbusServerE_t {};
} // unnamed namespace

template <> constexpr inline auto QModbusServer::qt_create_metaobjectdata<qt_meta_tag_ZN13QModbusServerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QModbusServer",
        "dataWritten",
        "",
        "QModbusDataUnit::RegisterType",
        "table",
        "address",
        "size",
        "Option",
        "DiagnosticRegister",
        "ExceptionStatusOffset",
        "DeviceBusy",
        "AsciiInputDelimiter",
        "ListenOnlyMode",
        "ServerIdentifier",
        "RunIndicatorStatus",
        "AdditionalData",
        "DeviceIdentification",
        "UserOption"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataWritten'
        QtMocHelpers::SignalData<void(QModbusDataUnit::RegisterType, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Option'
        QtMocHelpers::EnumData<enum Option>(7, 7, QMC::EnumFlags{}).add({
            {    8, Option::DiagnosticRegister },
            {    9, Option::ExceptionStatusOffset },
            {   10, Option::DeviceBusy },
            {   11, Option::AsciiInputDelimiter },
            {   12, Option::ListenOnlyMode },
            {   13, Option::ServerIdentifier },
            {   14, Option::RunIndicatorStatus },
            {   15, Option::AdditionalData },
            {   16, Option::DeviceIdentification },
            {   17, Option::UserOption },
        }),
    };
    return QtMocHelpers::metaObjectData<QModbusServer, qt_meta_tag_ZN13QModbusServerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QModbusServer::staticMetaObject = { {
    QMetaObject::SuperData::link<QModbusDevice::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QModbusServerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QModbusServerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QModbusServerE_t>.metaTypes,
    nullptr
} };

void QModbusServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QModbusServer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataWritten((*reinterpret_cast<std::add_pointer_t<QModbusDataUnit::RegisterType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModbusDataUnit::RegisterType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QModbusServer::*)(QModbusDataUnit::RegisterType , int , int )>(_a, &QModbusServer::dataWritten, 0))
            return;
    }
}

const QMetaObject *QModbusServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QModbusServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QModbusServerE_t>.strings))
        return static_cast<void*>(this);
    return QModbusDevice::qt_metacast(_clname);
}

int QModbusServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QModbusDevice::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QModbusServer::dataWritten(QModbusDataUnit::RegisterType _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
